﻿<?php defined( "_VALID_MOS" ) or die( "Direct Access to this location is not allowed." );?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN" "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<?php mosShowHead(); ?>
<?php echo '<meta http-equiv="Content-Type" content="text/html;', _ISO , '"/>', "\n" ;?>
<?php if ( $my->id ) { initEditor(); } ?>
<?php printf( '<link rel="stylesheet" href="%s/templates/%s/css/template_css.css" type="text/css"/>'."\n", $GLOBALS[mosConfig_live_site],$GLOBALS[cur_template] );?>
<?php printf( '<link rel="shortcut icon" href="%s/images/favicon.ico" />'."\n", $GLOBALS[mosConfig_live_site] );?>
</head>

<body>
<table class="layout">
	<tr><td colspan="3" class="cell"><div class="header"><?php mosLoadModules('header',0); ?></div></td></tr>
	<tr><td colspan="3" class="cell"><div class="navi"><?php mosLoadModules('navi',0); ?></div></td></tr>
	<tr>
		<td class="cell" width="20%"><div class="right"><?php mosLoadModules('right',0); ?></div><div class="left"><?php mosLoadModules('left',0); ?></div></td>
		<td class="cell" width="80%"><div class="main"><?php mosLoadModules('main',0); ?></div></td>
	</tr>
	<tr><td colspan="3" class="cell"><div class="navi"><?php mosLoadModules('navi',0); ?></div></td></tr>
	<tr><td colspan="3" class="cell"><div class="footer"><?php mosLoadModules('footer',0); ?></div></td></tr>
</table>
</body>
</html>
